% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bssdata_class.R
\name{load_bss_data}
\alias{load_bss_data}
\title{Load data for statistical analysis.}
\usage{
load_bss_data(
  type = "cbm",
  subjdir = "",
  csv = "",
  hemi = "left",
  smooth = 0,
  roiids = 0,
  roimeas = "gmthickness",
  measure = "",
  atlas = "",
  eddy = TRUE
)
}
\arguments{
\item{type}{character string denoting type of analysis. Should be cbm, tbm, or roi.}

\item{subjdir}{subject directory containing BrainSuite processed data.}

\item{csv}{filename of a comma separated (csv) file containing the subject demographic information.
The first column of this csv file
should be "subjID" and should have subject identifiers you wish to analyze. subjID can be alphanumeric
and should be exactly equal to the individual subject directory name.}

\item{hemi}{chaaracter string denoting the brain hemisphere. Should either be "left" or "right".}

\item{smooth}{numeric value denoting the smoothing level.}

\item{roiids}{numeric label identifiers for the regions of interest (ROI) type analysis.}

\item{roimeas}{character string for the ROI measure. Should either be "gmthickness", "gmvolume", or "wmvolume".}

\item{measure}{character specifying the brain imaging measure. If analyzing diffusion data, should be "FA".}

\item{atlas}{character specifying the file path prefix (all characters in the file name upto the first ".") for the custom atlas. If empty, the atlas will be read from the svreg.log file in the subject directory.
Otherwise, for example, if the atlas for tensor based morphometry is located at /path/to/atlas/myatlas.mri.bfc.nii.gz, then specify atlas="/path/to/atlas/myatlas".}

\item{eddy}{boolean for specifying if the diffusion images were eddy-current corrected or not.}
}
\description{
Loading data is usually the first step before running any statistical analysis.
Prior to using this function, BrainSuite and svreg should be run on all subjects.
If required, smoothing should be performed on cortical surface or volumetric image based measures.
A csv file containing subject demographic information should exist. The first column of this csv file
should have the subject identifiers. Subject identifiers can be alphanumeric
and should be exactly equal to the individual subject directory names.
}
\examples{
\dontrun{
my_cbm_data <- load_bss_data(type="cbm", subjdir = "/path/to/my/subjectdirectory",
csv = "/path/to/my/demographics.csv", hemi = "left", smooth = 2.5)

my_roi_data <- load_bss_data(type="roi", subjdir = "/path/to/my/subjectdirectory",
csv="/path/to/my/demographics.csv", roiids=501, roimeas="gmthickness")
}

}
